
/***********************************************************************
 *
 * Copyright (c) Palm Computing 1997 -- All Rights Reserved
 *
 * PROJECT:  Elaine Proxy Server
 * FILE:	 CTPProxyPrv.h
 * AUTHOR:	 Ron Marianetti 6/24/97
 *
 * DESCRIPTION:
 *	 Header for the CTP Proxy service component of Elaine. 
 **********************************************************************/

#ifndef _CTP_H_
#define _CTP_H_ 


//##########################################################
// CTP Commands
// This is the CTP command UIntV which is sent in every
//  CTP Request in the common area (CTPReqCommon)
//##########################################################
typedef enum {
	ctpCmdReqURL = 0,				// request URL
	ctpCmdReqMail = 1,				// request mail
	ctpCmdEcho = 2,
	ctpCmdMsgGen = 3,
	ctpCmdDiscard = 4
	} CTPCmdEnum;


//##########################################################
// CTP Content Conversion Types
// The requestor can pass one of these constants in the
//   ctpExtConvertTo extension in order to specify the
//	 the type of content conversion desired.
// If the extension is missing, then ctpConvCML is assumed.
//##########################################################
typedef enum {
	ctpConvCML = 0,					// CML 
	ctpConvCML8Bit = 1,				// CML in 8-bit debug form
	ctpConvCMLLZSS = 2,				// CML with LZSS
	ctpConvNone = 3					// Return in native web format.
									//   When this is specified, then the response
									//   will include the ctpRspExtContentType
									//   and ctpRspExtContentEncoding extensions
	} ctpConvEnum;


//##########################################################
// CTP Request Extensions
// These are the defined extension IDs that can appear
//  in the extensions area of a CTP request
//##########################################################

// Extensions defined for the ctpCmdReqMail command....
typedef enum {
	ctpExtIncHTTPResponse = 1,		// include HTTP response header in data
									//   only applicable if ctpExtConvertTo
									//   is set to ctpConvNone

	ctpExtNetID = 128,				// Followed by length byte of 4 and
									//  4 byte networkID..
									//  Must be specified when using TCP
									//  because tunneler is not used.

	ctpExtUserID = 129,				// Followed by length byte of 4 and
									//  4 byte userID.
									//  Must be specified when using TCP
									//  because Mobitex MAN# is not available

	ctpExtUserPW = 130,				// Followed by length byte of 16 and
									//  128 bit (16 byte) MD5 hashed password. 
									//  Must be specified when using TCP
									//  because Mobitex MAN# is not available

	ctpExtUserName = 131,			// Followed by length byte  and
									//  ascii user name string. 
									//  This or ctpExtUserID must be specified 
									//  when using TCP because Mobitex MAN# 
									//  is not available

	ctpExtServer = 132,				// Followed by a length byte of 1 and
									//  8 bits (1 byte) of server behavior
									//  flags.
	ctpExtConvertTo = 133			// Followed by length byte of 1 and
									//   a 1 byte conversion identifier
									//   ctpConvXXX. If not present then
									//   ctpConvCML is assumed. 

	} CTPReqExtEnum;



//##########################################################
// CTP Response Extensions
// These are the defined extension IDs that can appear
//  in the extensions area of a CTP  response
//##########################################################
// Extensions defined for the ctpCmdReqURL response
typedef enum {
	ctpExtContentType = 128,		// Followed by length byte of 'len' and
									//   a 'len' byte string containing the
									//   MIME type of the content. This extension
									//   is only returned when the request has
									//   a ctpReqExtConverTo value of ctpConvNone
	
	ctpExtContentEncoding = 129,	// Followed by length byte of 'len' and
									//   a 'len' byte string containing the
									//   encoding type ("x-gzip, "compress", "lz77", 
									//   etc.)
									//   This extension is only returned when the 
									//   request has a ctpReqExtConverTo value of 
									//   ctpConvNone

	ctpExtUncompressSize = 130		// Followed by length byte of 4 and
									//   a DWord containing the uncompressed
									//   size of the content. Currently only
									//   sent when the requested content conversion
									//   type is ctpConvCMLLZSS


	} CTPRspExtURLEnum;




//##########################################################
// CTP Network IDs.
// These are used along with the userID to identify a user's
//   mailbox account. All mailboxes created for the Mobitex
//   network with have a network ID of 0. The network ID
//   is passed along with the userID to the mail proxy. 
// For wireless networks, the tunneler fills in the network
//  ID into the ?? field of the tunneled IP packets. For wireline
//  access, the client must include the network ID in the extensions
//  field of the CTP mail request. 
//##########################################################
typedef enum {
	ctpNetIDMobitex = 0,
	ctpNetIDUnknown = 0xFFFF
	} CTPNetIDEnum;


//##########################################################
// CTP Schemes
// This is the scheme encoding which is used as a field
//  in the document address portion in a URL request
//##########################################################
typedef enum {
	ctpSchemeHTTP = 0,					// http://
	ctpSchemeHTTPS = 1,					// https://
	ctpSchemeFTP = 2,					// ftp://
	ctpSchemeEmpty = 7
	} CTPSchemeEnum;


//##########################################################
// CTP Errors
// These are the possible error codes returned in a CTP response
//##########################################################
typedef enum {
	ctpErrNone = 0,
	ctpErrMalformedRequest,				// malformed request from client
										//  no extra data
	ctpErrUnknownCmd,					// unsupported CTP command
										//  no extra data
	ctpErrProxy,						// err on Proxy 
										//  Data:
										//    DWord		proxyErr
										//	  Char		errMsg[]
	ctpErrServer,						// err on Server
										//  Data:
										//    DWord		serverErr
										//	  Char		errMsg[]
	ctpErrTruncated = 0x8000			// response is truncated
	} CTPErrEnum;





//=====================================================
// Functions
//====================================================
#ifdef __cplusplus
extern "C" {
#endif

DWord	CtpURLEncode(CharPtr urlP, BytePtr dstP, DWordPtr dstBitOffsetP,
			DWord	dstBitLen);

DWord	CtpURLDecode(BytePtr srcP, DWordPtr srcBitOffsetP,
			CharPtr urlP, DWord	urlBufSize);

// Convert a base26 ascii string as used in a CTP URL into an
//  integer. Return's 0 if no error, updates *strPP to point
//  to next character past base26 ascii string. 
DWord	CtpBase26AToI(CharPtr* strPP, DWordPtr intP);


#ifdef __cplusplus
}
#endif

#endif /* _CTP_H_ */
