/*********************************************************************** 
 *
 *	Copyright (c) Palm Computing 1996 -- All Rights Reserved
 *
 * PROJECT:  Pilot INet Library
 * FILE:     INetMgrMail.h
 * AUTHOR:	 Ron Marianetti 6/2/97
 *
 * DESCRIPTION:
 *	  This header file contains the Mail specific equates for the
 *		Internet Library. It gets included by INetMgr.h
 *
 **********************************************************************/
#ifndef 	__INETMGR_MAIL_H__
#define	__INETMGR_MAIL_H__




/********************************************************************
 * Mail Attributes which can be set/get using the
 *  INetLibMailAttrSet/Get calls.
 *
 * Generally, attributes are only set BEFORE calling 
 *		InetLibSockMailReqCreate
 * and attributes are only gotten AFTER the mail response header
 *		has been received. 
 ********************************************************************/
typedef enum {

	// local error trying to communicate with server, if any
	inetMailAttrCommErr,							// DWord, read-only
	
	// New Mail Request attributes, these should be set immediately
	//  after calling INetLibMailReqCreate.  
	inetMailAttrReqEncrypted					// Byte (Boolean)	
	
	// DOLATER... we will probably need additional encryption 
	//  parameters here, or, it might make more sense to put
	//  them as INet client settings in the INetSettingEnum
	//  settings list. 
	
	} inetMailAttrEnum;




/********************************************************************
 * Mail commands and parameter blocks  for the INetLibSockMailReqCreate
 *		and INetLibSockMailReqAdd routines.
 *
 * These parameter blocks must be filled in by the caller before they
 *		call INetLibSockMailReqCreate to start the request formation
 *		and for every INetLibSockMailReqAdd. 
 ********************************************************************/
typedef struct {
	Word	hi;										// hi 2 bytes
	DWord	lo;										// lo 4 bytes of unique ID
	} INetMailUIDType;
 
typedef enum {
	inetMailCmdNew=0,							// specified through getNewMail flag
														//  in MailReqCreate().
	inetMailCmdSend=1,
	inetMailCmdGetMore=2,
	inetMailCmdServer=3
	} INetMailCmdEnum;
	
		
// The INetMailCmdNewPtr is used for the ReqCreate call

#define		inetMailMaxUsername 32 
#define		inetMailMaxPassword 32
typedef struct {
	INetMailUIDType	id;
	DWord					previewSize;
	CharPtr				headerFieldsP;
	
	DWord					availMemory;			// available memory
	DWord					truncationSize;		// truncation size
	DWord					networkID;				// network ID
	Char 					username[inetMailMaxUsername];	// user name, if any
	Char 					password[inetMailMaxPassword];	// password, if any
	} INetMailNewType, *INetMailNewPtr;


// The INetMailSendPtr is used for the ReqAdd call
typedef struct {
	Word					priority;
	Byte					confirmRead;
	Byte					confirmDelivery;
	Word					attachmentCount;
	void*					attachmentsP;
	DWord					msgSize;
	void*					msgP;
	} INetMailSendType, *INetMailSendPtr;


// The INetMailGetMorePtr is used for the ReqAdd call
typedef struct {
	INetMailUIDType	id;
	DWord					bodyEndOffset;
	CharPtr				headerFieldsP;
	} INetMailGetMoreType, *INetMailGetMorePtr;


// The INetMailServerPtr is used for the ReqAdd call
typedef struct {
	DWord					serverCmd;
	DWord					serverParamsLen;
	BytePtr				serverParamsP;
	} INetMailServerType, *INetMailServerPtr;



/********************************************************************
 * The INetLibSockRead call returns the following data:
 * 
 *  INetMailHeaderType 	headerInfo
 *  if (headerInfo.proxyErr == 0 && headerInfo.serverErr == 0) 
 *		 do {
 *		 	INetMailRspType	mailRsp
 *		 	if (	mailRsp.dataSize)
 *			  	Byte[mailRsp.dataSize]		data
 *  		} while (!mailRsp.kind != inetMailRspEnd)  
 *
 * Thus, the application must issue a read for a INetMailHeaderType
 *		struct, check for a server or proxy error, then issue
 *		a read for a INetMailRspType struct, check it's dataSize
 *		and read the following data if any, etc. etc. 
 *  
 ********************************************************************/
typedef enum {
	inetMailContentJerry = 0
	} INetMailContentTypeEnum;
	
// This structure is the first thing returned from a read call to a
//  Mail socket. If serverErr is 0 and proxyErr is 0, the caller
//  should next issue a read for a INetMailRspType. 
// If serverErr is not 0, then there will be 'rspSize' bytes of
//  data that can be read out of the socket that contains the
//  server error text. 
typedef struct {
	DWord		proxyErr;			// proxy error code, if any
	DWord		serverErr;			// server error code, if any
	DWord		rspSize;				// total size of response in bytes. If
										//   serverErr is not 0, this is the size of
										//   the following error text in the socket. 
	
	Word		contentType;		// inetMailContentXXX, format of all following
										//  new mail responses
	
	Word		newMsgs;				// how many new msgs are in the response
	Word		updMsgs;				// how many updated msgs are in the response
	
	Byte		moreMailAvail;		// true if more mail is on the server
	
	} INetMailHeaderType;
	
	
// These are the possible values for the kind field of a INetMailRspType.
typedef enum {
	inetMailRspEnd	=0,	   	// always the last one in the response
	inetMailRspNewMsg,
	inetMailRspMsgAttachment,
	inetMailRspUpdMsg,
	inetMailRspAck
	} INetMailRspEnum;
	
	
// The INetMailRspType is a union of possible response kinds. It is the next
//  thing returned after a  INetMailHeaderType and is followed by
//  'dataSize' bytes of data and then another INetMailHeaderType. 
typedef struct {
	Word	kind;						// inetMailRspXXX
	DWord	dataSize;				// size of following data, if any
	
	union {
		struct {
			DWord		generic[8];		// reserve 32 bytes 
			} generic;
			
		struct {
			INetMailUIDType	id;	// mail ID
			Word		addrType;		// sent to, cc, or bcc
			DWord		bodyEndOffset;	// where the mssage left off, 0 if msg complete
			Word		priority;		// priority of message
			DWord		serverMsgSize;	// server message size
			Word		serverNoteID;	// server error message, if any
			Word		attachmentCount;	// number of attachments that follow
			DWord		timeStamp;			//time stamp of the message
			} newMsg;
			
		struct {
			DWord		type;				// attachment type
			} attachment;
			
		struct {
			INetMailUIDType	id;	// mail ID
			DWord		bodyEndOffset;	// where the mssage left off, 0 if msg complete
			Word		serverNoteID;	// server error message, if any
			Word		attachmentCount;	// number of attachments that follow
			} updMsg;
			
		struct {
			Word		cmd;				// inetMailCmdXXX this is a response to
			DWord		serverErr;		// server error code
			INetMailUIDType	id; 	// mail mesage ID this concerns
			DWord		dataType;		// type of data that follows
			} ack;
		} params;			
	
	} INetMailRspType;
	




/********************************************************************
 * INet Library Mail specific functions. 
 * The trap numbers for these calls are defined in INetMgr.h
 *		which includes this header file. 
 ********************************************************************/

Err				INetLibSockMailReqCreate(Word libRefnum, Handle sockH,
						INetMailNewPtr paramsP, Word paramsLen, SDWord timeout)
						SYS_TRAP(inetLibTrapSockMailReqCreate);
						
Err				INetLibSockMailAttrSet(Word libRefnum, Handle sockH, 
							Word /*inetMailAttrEnum*/ attr, Word attrIndex, 
							BytePtr bufP,  Word bufLen, Word flags)
						SYS_TRAP(inetLibTrapSockMailAttrSet);
						
Err				INetLibSockMailReqAdd(Word libRefnum, Handle sockH,
							Word /*inetMailCmdEnum*/ mailCmd,
							void*  paramsP,  Word paramsLen)
						SYS_TRAP(inetLibTrapSockMailReqAdd);

Err				INetLibSockMailReqSend(Word libRefnum, Handle sockH)
						SYS_TRAP(inetLibTrapSockMailReqSend);

Err				INetLibSockMailAttrGet(Word libRefnum, Handle sockH, 
							Word /*inetMailAttrEnum*/ attr, Word attrIndex,
							VoidPtr bufP, DWordPtr bufLenP)
						SYS_TRAP(inetLibTrapSockMailAttrGet);

Err				InetLibTrapSockMailQueryProgress(Word libRefnum, Handle sockH,
						DWordPtr receivedBytes, DWordPtr usedBits, DWordPtr expandedBytes)
						SYS_TRAP(inetLibTrapSockMailQueryProgress);
						


#endif 	//__INETMGR_MAIL_H__
