/*******************************************************************
 * 							 Pilot Software
 *
 *		 Copyright(c) 1994, Palm Computing Inc., All Rights Reserved  
 *
 *-------------------------------------------------------------------
 * FileName:
 *		SerialLib68328.h
 *
 * Description:
 *		Include file for 68328 Serial Library
 *
 * History:
 *   	2/7/95 Created by Ron Marianetti
 *		vmk	8/21/95	Added defQData field to serial globals
 *
 *******************************************************************/

#ifndef __SERIAL_LIB_68328_H
#define __SERIAL_LIB_68328_H


// Pilot common definitions
#include <SerialMgr.h>

// scanning mode states
#define scmOff								0	// scanning disabled
#define scmIdle							1	// idle while port is in use
#define scmActive							2	// active 
#define scmOpening						3  // scanning is being activated

/********************************************************************
 * Serial Globals 
 ********************************************************************/
typedef struct SerGlobalsType {
	UInt					openCount;			// # of times we've been opened
	Int					port;					// DOLATER... NOT NEEDED ???
	SerSettingsType	settings;
	Word					lineErrors;			// line errors bitfield
	
	#ifndef BUILDING_FOR_DEBUGGER
	// Receive Queue. When the queue is empty, qStart == qEnd. When the queue
	//  is full, qStart = qEnd-1 (taking wrap-around into account if necessary).
	Word					qStart;				// start offset of queue
	Word					qEnd;					// end offset of queue
	Word					qSize;				// size of queue
	Ptr					qData;				// pointer to queue data
	Ptr					defQData;			// pointer to default queue data
	
	// Receive Queue semaphore info
	ProcPtr				wakeupHandler;		// Wakeup handler, if installed
	DWord					wakeupRefcon;		// refcon for wakeup handler
	Word					smSignalSize;		// How much the semaphore is waiting for
	DWord					smID;					// semaphore ID
	
	DWord					lastRcvTicks;		// tick count of last received char

	// For debugging
	Word					numReceived;		// # of chars received since serial manager opened
	Word					lastErrorStatus;	// receiver status of last line error
	Word					numRcvErrors;		// # of receive line errors since serial manager opened
	#endif

	// IrDA stuff
	Boolean				irdaMode;			// true if UART is set to IrDA mode
	Byte					scanningMode;     // current state of Ir scanning mode
	Boolean				scanIrdaMode;		// true if scanning should be done in irda mode
	SerWakeupHandler	scanWakeHandler;	// scannning Wakeup handler,
	DWord					scanWakeParam;	   // parameter to pass to wake handler

	} SerGlobalsType;
typedef SerGlobalsType*	SerGlobalsPtr;

#define	serDefaultRcvBufferSize	0x200

#endif	//__SERIAL_LIB_68328_H
