/*******************************************************************
 * 							 Pilot Software
 *
 *		 Copyright(c) 1995, Palm Computing Inc., All Rights Reserved
 *
 *-------------------------------------------------------------------
 * FileName:
 *		SoundPrv.h
 *
 * Description:
 *		Private Include file for Sound Manager
 *
 * History:
 *   	4/11/95  VMK - Created by Vitaly Kruglikov
 *
 *******************************************************************/

#ifdef	NON_PORTABLE

#ifndef __SOUNDPRV_H__
#define __SOUNDPRV_H__

// Convert milliseconds to PilotOS ticks
#define sndMilliSecToPilotTicks(milliSec)	(((milliSec) * (DWord)sysTicksPerSecond + 500) / 1000)

#define sndPilotTicksToMilliSec(ticks)	(((ticks) * 1000L) / sysTicksPerSecond)


/************************************************************
 * Sound Manager constants
 *************************************************************/

#define	sndSamplingRate					8000	// 8 kHz


// DOLATER: determine appropriate values experimentally (TBD)
#define	sndBeepDurationMSec				70				// msec
#define	sndConfirmationDurationMSec	70				// msec
#define	sndClickDurationMSec				9				// msec

// These frequencies are more audible on the current hardware.
#define	sndInfoFreq							500			// Hz
#define	sndWarningFreq						500			// Hz
#define	sndErrorFreq						500			// Hz
#define	sndConfirmationFreq				500			// Hz
#define	sndStartUpFreq						1000			// Hz
#define	sndClickFreq						200			// Hz


/*******************************************************************
 * Sound Manager Globals
 *
 *******************************************************************/
typedef struct SndGlobalsType {
	Long				smID;					// semaphore id for data access integrity
	Byte				sysAmp;				// system sound amplitude(0-sndMaxVolume)
	Byte				alarmAmp;			// alarm sound amplitude(0-sndMaxVolume)
	Byte				defAmp;				// default amplitude for other sounds(0-sndMaxVolume)
	WordPtr			wMidiFrqTabP;		// pointer to MIDI frequency table
#if EMULATION_LEVEL != EMULATION_NONE
	ULong				timerID;				// "sound-kill" timer ID (emulation only)
#endif
	} SndGlobalsType;

typedef SndGlobalsType*		SndGlobalsPtr;



/********************************************************************
 * Interal Sound Manager Routines
 ********************************************************************/
#ifdef __cplusplus
extern "C" {
#endif

// Internally-used Sound Manager functions
extern Boolean ISndFrqOn(DWord dwFrq, Word wAmp);
extern void ISndSoundOff(void);
extern Err ISndMidiInit(SndGlobalsPtr gP);
extern Err ISndMidiNoteOn(SndGlobalsPtr gP, Byte bKey, Byte bVel, UInt relAmp, Boolean* soundOnP);



#ifdef __cplusplus 
}
#endif


#endif  // __SOUNDPRV_H__
#endif  // NON_PORTABLE
