/*******************************************************************
 * 							 Pilot Software
 *
 *		 Copyright(c) 1994, Palm Computing Inc., All Rights Reserved
 *
 *-------------------------------------------------------------------
 * FileName:
 *		SysConfigPrv.h
 *
 * Description:
 *		Private system configuration defines
 *
 * History:
 *   	8/23/96  RM - Created by Ron Marianetti
 *   12/10/97  SL - Rewrote memCalcDynamicRAMSize macro
 *
 *******************************************************************/

#ifdef	NON_PORTABLE

#ifndef __SYSCONFIGPRV_H__
#define __SYSCONFIGPRV_H__




/************************************************************
 * Private Memory Manager Constants
 *************************************************************/
#define mem32K		0x008000
#define mem64K		0x010000
#define mem96K		0x018000
#define mem128K	0x020000
#define mem256K	0x040000
#define mem512K	0x080000
#define mem1MB		0x100000
#define mem2MB		0x200000


//==========================================================================
// Default size of the dynamic heap
// This macro accepts the total RAM in card 0 as a parameter and returns
//  the number of bytes to assign to the dynamic heap
// 
// IMPORTANT!! Only certain sizes are supported by the hardware. This section
//   makes sure that the setting is one of the sizes supported by the hardware.
//   The routine HwrGetRAMSize() in ROMHardwareXXX.c is responsible for setting
//   up the chip select registers appropriately for each possible value of
//   DYN_MEM_SIZE.  
//
// <RM> 1-16-98, Replaced DYN_MEM_SIZE equate with DYN_MEM_SIZE_MIN &
//   DYN_MEM_SiZE_MAX
// <SL> 1-20-98, Added DYN_MEM_SIZE_EXTRA for Jerry and Cessna...
// WAS:
/*
	#ifndef DYN_MEM_SIZE
	#error	Build option DYN_MEM_SIZE not setup
	#endif

	#if 		DYN_MEM_SIZE == mem128K
	#define	memCalcDynamicRAMSize(totalSize) 		\
			((totalSize > mem1MB ) ? mem128K : ((totalSize > mem128K) ? mem96K : mem32K))
			// EvenBigger: 	>1MB --> 128K;							>128KB --> 96K;	else --> 32K

	#elif		DYN_MEM_SIZE == mem96K
		#define	memCalcDynamicRAMSize(totalSize) 	\
			((totalSize > mem1MB ) ? mem96K : ((totalSize > mem128K) ? mem64K : mem32K))
			// EvenBigger: 	>1MB --> 96K;							>128KB --> 64K;	else --> 32K

	#elif 	DYN_MEM_SIZE == mem64K
		#define	memCalcDynamicRAMSize(totalSize) 	\
			((totalSize > mem128K) ? mem64K : mem32K)
			// BigHeap: >128KB --> 64K; else 32K

	#elif 	DYN_MEM_SIZE == mem32K
		#define	memCalcDynamicRAMSize(totalSize)	mem32K
			// SmallHeap: always 32K

	#else
		#error	"Unsupported setting for DYN_MEM_SIZE!!"

	#endif
*/
//==========================================================================

#ifdef	DYN_MEM_SIZE
	#error	Error! Obsolete define DYN_MEM_SIZE used
#endif

#ifndef DYN_MEM_SIZE_MIN
	#error	Build option DYN_MEM_SIZE_MIN not setup
#endif

#ifndef DYN_MEM_SIZE_MAX
	#error	Build option DYN_MEM_SIZE_MAX not setup
#endif

#ifndef DYN_MEM_SIZE_EXTRA
	#error	Build option DYN_MEM_SIZE_EXTRA not setup
#endif

// PalmOS 1.0 always has a 32K dynamic heap
// PalmOS 2.0 Personal ROM always has a 32K dynamic heap
// PalmOS 2.0 Professional ROM always has a 64K dynamic heap
//
// PalmOS 3.0 default dynamic heap calcuation:
// 	Systems with >1 MB of RAM get a 96K dynamic heap
// 	Systems with >128K of RAM get a 64K dynamic heap
// 	Systems with  128K of RAM get a 32K dynamic heap
//
// Some systems may have extra requirements in order to
// function regardless of how much total RAM is installed.
// This gets specified in the DYN_MEM_SIZE_EXTRA build parm.
// Since this extra memory is used by these systems, it is
// not generally available for application use.

#define	prvDefaultSize(totalSize)				\
		((totalSize > mem1MB ) ? mem96K : 		\
		 (totalSize > mem128K) ? mem64K :  		\
		  mem32K) + DYN_MEM_SIZE_EXTRA
		
#define	memCalcDynamicRAMSize(totalSize)		\
		((prvDefaultSize(totalSize) > DYN_MEM_SIZE_MAX) ? DYN_MEM_SIZE_MAX : \
		 (prvDefaultSize(totalSize) < DYN_MEM_SIZE_MIN) ? DYN_MEM_SIZE_MIN : \
		 prvDefaultSize(totalSize))


#define	memCalcDynamicHeapSize(totalSize) 		\
		(memCalcDynamicRAMSize(totalSize)-sysLowMemSize)


#endif  // __SYSCONFIGPRV_H__
#endif //NON_PORTABLE
